'use strict';
'use es6';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _maps = require('@google/maps');

var _maps2 = _interopRequireDefault(_maps);

var _currentLocation = require('current-location');

var _currentLocation2 = _interopRequireDefault(_currentLocation);

var _dotenv = require('dotenv');

var _dotenv2 = _interopRequireDefault(_dotenv);

var _Coordinate = require('../data/Coordinate');

var _Coordinate2 = _interopRequireDefault(_Coordinate);

var _GeocodeTranslator = require('./translators/GeocodeTranslator');

var _GeocodeTranslator2 = _interopRequireDefault(_GeocodeTranslator);

var _CurrentLocationTranslator = require('./translators/CurrentLocationTranslator');

var _CurrentLocationTranslator2 = _interopRequireDefault(_CurrentLocationTranslator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

_dotenv2.default.load();

var GeocodeService = function () {
  function GeocodeService() {
    _classCallCheck(this, GeocodeService);

    this.googleMapsClient = _maps2.default.createClient({
      key: process.env.GOOGLE_GEOCODE_API_KEY
    });
  }

  _createClass(GeocodeService, [{
    key: 'getCurrentLocationData',
    value: function getCurrentLocationData() {
      return new Promise(function (resolve, reject) {
        (0, _currentLocation2.default)(function (error, data) {
          if (error !== null) {
            return reject(error);
          }

          resolve(data);
        });
      });
    }
  }, {
    key: 'getReverseGeocodeAddressData',
    value: function getReverseGeocodeAddressData(coordinate) {
      var _this = this;

      return new Promise(function (resolve, reject) {
        _this.googleMapsClient.reverseGeocode({
          latlng: [coordinate.latitude, coordinate.longitude]
        }, function (error, data) {
          if (error !== null) {
            return reject(error);
          }

          resolve(data.json);
        });
      });
    }
  }, {
    key: 'getGeocodeCoordinatesData',
    value: function getGeocodeCoordinatesData(address) {
      var _this2 = this;

      return new Promise(function (resolve, reject) {
        _this2.googleMapsClient.geocode({
          address: address
        }, function (error, data) {
          if (error !== null) {
            return reject(error);
          }

          resolve(data.json);
        });
      });
    }
  }, {
    key: 'getLocation',
    value: function getLocation(address) {
      if (!address) {
        return this.getCurrentLocationData().then(function (response) {
          return _CurrentLocationTranslator2.default.translate(response);
        })
        // Uncomment below for showing current location address
        // .then((coordinate) => {
        //   return this.getReverseGeocodeAddressData(coordinate)
        // })
        // .then((response) => {
        //   return GeocodeTranslator.translate(response);
        // })
        // .then((locations) => {
        //   return GeocodeService.getFirstLocation(locations);
        // })
        .catch(function (error) {
          throw error;
        });
      }

      return this.getGeocodeCoordinatesData(address).then(function (response) {
        return _GeocodeTranslator2.default.translate(response);
      }).then(function (locations) {
        return GeocodeService.getFirstLocation(locations);
      }).catch(function (error) {
        throw error;
      });
    }
  }], [{
    key: 'getFirstLocation',
    value: function getFirstLocation(locations) {
      if (locations.isEmpty()) {
        throw new RangeError('no locations for address');
      }

      return locations.first();
    }
  }]);

  return GeocodeService;
}();

exports.default = GeocodeService;