'use strict';
'use es6';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _immutable = require('immutable');

var _lyftNode = require('lyft-node');

var _lyftNode2 = _interopRequireDefault(_lyftNode);

var _dotenv = require('dotenv');

var _dotenv2 = _interopRequireDefault(_dotenv);

var _GeocodeService = require('./GeocodeService');

var _GeocodeService2 = _interopRequireDefault(_GeocodeService);

var _RideTypes = require('../data/RideTypes');

var _RideTypes2 = _interopRequireDefault(_RideTypes);

var _RideTypesTranslator = require('./translators/RideTypesTranslator');

var _RideTypesTranslator2 = _interopRequireDefault(_RideTypesTranslator);

var _NearbyDrivers = require('../data/NearbyDrivers');

var _NearbyDrivers2 = _interopRequireDefault(_NearbyDrivers);

var _NearbyDriversTranslator = require('./translators/NearbyDriversTranslator');

var _NearbyDriversTranslator2 = _interopRequireDefault(_NearbyDriversTranslator);

var _DriverEtas = require('../data/DriverEtas');

var _DriverEtas2 = _interopRequireDefault(_DriverEtas);

var _DriverEtasTranslator = require('./translators/DriverEtasTranslator');

var _DriverEtasTranslator2 = _interopRequireDefault(_DriverEtasTranslator);

var _RideEstimates = require('../data/RideEstimates');

var _RideEstimates2 = _interopRequireDefault(_RideEstimates);

var _RideEstimatesTranslator = require('./translators/RideEstimatesTranslator');

var _RideEstimatesTranslator2 = _interopRequireDefault(_RideEstimatesTranslator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

_dotenv2.default.load();

var LyftService = function () {
  function LyftService() {
    _classCallCheck(this, LyftService);

    this.lyftApi = new _lyftNode2.default(process.env.LYFT_CLIENT_ID, process.env.LYFT_CLIENT_SECRET);
    this.geocodeService = new _GeocodeService2.default();
  }

  _createClass(LyftService, [{
    key: 'getRideTypes',
    value: function getRideTypes(address) {
      var _this = this;

      return this.geocodeService.getLocation(address).then(function (location) {
        var query = {
          start: {
            latitude: location.coordinate.latitude,
            longitude: location.coordinate.longitude
          }
        };

        return _this.lyftApi.getRideTypes(query).then(function (response) {
          return new _RideTypes2.default({
            location: location,
            rideTypes: _RideTypesTranslator2.default.translate(response)
          });
        }).catch(function (error) {
          throw error;
        });
      }).catch(function (error) {
        throw error;
      });
    }
  }, {
    key: 'getDriverEtas',
    value: function getDriverEtas(address) {
      var _this2 = this;

      return this.geocodeService.getLocation(address).then(function (location) {
        var query = {
          start: {
            latitude: location.coordinate.latitude,
            longitude: location.coordinate.longitude
          }
        };

        return _this2.lyftApi.getDriverEta(query).then(function (response) {
          return new _DriverEtas2.default({
            location: location,
            driverEtas: _DriverEtasTranslator2.default.translate(response)
          });
        }).catch(function (error) {
          throw error;
        });
      }).catch(function (error) {
        throw error;
      });
    }
  }, {
    key: 'getRideEstimates',
    value: function getRideEstimates(addresses) {
      var _this3 = this;

      var startLocation = this.geocodeService.getLocation(addresses.startAddress).then(function (location) {
        return location;
      }).catch(function (error) {
        throw error;
      });

      var endLocation = this.geocodeService.getLocation(addresses.endAddress).then(function (location) {
        return location;
      }).catch(function (error) {
        throw error;
      });

      return Promise.all([startLocation, endLocation]).then(function (locations) {
        var query = {
          start: {
            latitude: locations[0].coordinate.latitude,
            longitude: locations[0].coordinate.longitude
          },
          end: {
            latitude: locations[1].coordinate.latitude,
            longitude: locations[1].coordinate.longitude
          }
        };

        return _this3.lyftApi.getRideEstimates(query).then(function (response) {
          return new _RideEstimates2.default({
            start: locations[0],
            end: locations[1],
            costEstimates: _RideEstimatesTranslator2.default.translate(response)
          });
        }).catch(function (error) {
          throw error;
        });
      }).catch(function (error) {
        throw error;
      });
    }
  }, {
    key: 'getNearbyDrivers',
    value: function getNearbyDrivers(address) {
      var _this4 = this;

      return this.geocodeService.getLocation(address).then(function (location) {
        var query = {
          start: {
            latitude: location.coordinate.latitude,
            longitude: location.coordinate.longitude
          }
        };

        return _this4.lyftApi.getNearbyDrivers(query).then(function (response) {
          return new _NearbyDrivers2.default({
            location: location,
            nearbyDrivers: _NearbyDriversTranslator2.default.translate(response, location)
          });
        }).catch(function (error) {
          throw error;
        });
      }).catch(function (error) {
        throw error;
      });
    }
  }]);

  return LyftService;
}();

exports.default = LyftService;