'use strict';
'use es6';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _nodeEmoji = require('node-emoji');

var _nodeEmoji2 = _interopRequireDefault(_nodeEmoji);

var _immutable = require('immutable');

var _cliTable = require('cli-table2');

var _cliTable2 = _interopRequireDefault(_cliTable);

var _CostEstimateFormatter = require('../formatters/CostEstimateFormatter');

var _CostEstimateFormatter2 = _interopRequireDefault(_CostEstimateFormatter);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

// import Utilities from '../../../Utilities';

var RideEstimatesTableBuilder = function () {
  function RideEstimatesTableBuilder() {
    _classCallCheck(this, RideEstimatesTableBuilder);
  }

  _createClass(RideEstimatesTableBuilder, null, [{
    key: 'build',
    value: function build(rideEstimates) {
      var table = RideEstimatesTableBuilder.buildInitialTable();

      var costEstimateRows = rideEstimates.costEstimates.map(function (costEstimate) {
        return RideEstimatesTableBuilder.buildCostEstimateRow(costEstimate);
      });

      costEstimateRows = costEstimateRows.sort(RideEstimatesTableBuilder.sortByDisplayName);

      costEstimateRows.forEach(function (costEstimateRow) {
        table.push(costEstimateRow);
      });

      table.push(RideEstimatesTableBuilder.buildLocationRow(rideEstimates.start.name, false));
      table.push(RideEstimatesTableBuilder.buildLocationRow(rideEstimates.end.name, true));

      return table.toString();
    }
  }, {
    key: 'getTableHeaders',
    value: function getTableHeaders() {
      return _immutable.List.of(_nodeEmoji2.default.get('red_car'), _nodeEmoji2.default.get('money_with_wings'), _nodeEmoji2.default.get('arrows_clockwise'), _nodeEmoji2.default.get('hourglass_flowing_sand'), _nodeEmoji2.default.get('boom') + ' Primetime' + _nodeEmoji2.default.get('boom'));
    }
  }, {
    key: 'buildInitialTable',
    value: function buildInitialTable() {
      var table = new _cliTable2.default();
      var formattedHeaders = (0, _immutable.List)(RideEstimatesTableBuilder.getTableHeaders().map(function (header) {
        return (0, _immutable.Map)({ content: header, hAlign: 'center' });
      }));
      table.push(formattedHeaders.toJS());
      return table;
    }
  }, {
    key: 'buildCostEstimateRow',
    value: function buildCostEstimateRow(costEstimate) {
      // TODO: Check for costEstimate.isValidEstimate
      return [costEstimate.displayName, _CostEstimateFormatter2.default.formatRange(costEstimate.priceRange), _CostEstimateFormatter2.default.formatDistance(costEstimate.estimatedDistance), _CostEstimateFormatter2.default.formatDuration(costEstimate.estimatedDuration), RideEstimatesTableBuilder.buildPrimetimePercentageSymbol(costEstimate.primetimePercentage).toJS()];
    }
  }, {
    key: 'buildPrimetimePercentageSymbol',
    value: function buildPrimetimePercentageSymbol(primetimePercentage) {
      var primetime = primetimePercentage + '%';

      if (primetimePercentage === 0) {
        primetime = primetime + ' ' + _nodeEmoji2.default.get('slightly_smiling_face');
      } else if (primetimePercentage <= 25) {
        primetime = primetime + ' ' + _nodeEmoji2.default.get('confused');
      } else if (primetimePercentage <= 50) {
        primetime = primetime + ' ' + _nodeEmoji2.default.get('slightly_frowning_face');
      } else if (primetimePercentage <= 75) {
        primetime = primetime + ' ' + _nodeEmoji2.default.get('cry');
      } else {
        primetime = primetime + ' ' + _nodeEmoji2.default.get('weary');
      }

      return (0, _immutable.Map)({
        content: primetime,
        hAlign: 'center'
      });
    }
  }, {
    key: 'buildLocationRow',
    value: function buildLocationRow(name, isEnd) {
      var symbol = isEnd ? _nodeEmoji2.default.get('end') : _nodeEmoji2.default.get('round_pushpin');
      return [{
        colSpan: 1,
        content: symbol,
        hAlign: 'center'
      }, {
        colSpan: 4,
        content: name
      }];
    }
  }, {
    key: 'sortByDisplayName',
    value: function sortByDisplayName(costEstimate1, costEstimate2) {
      var displayName1 = costEstimate1[0].toLowerCase();
      var displayName2 = costEstimate2[0].toLowerCase();

      if (displayName1 < displayName2) {
        return -1;
      }
      if (displayName1 > displayName2) {
        return 1;
      }

      return 0;
    }
  }]);

  return RideEstimatesTableBuilder;
}();

exports.default = RideEstimatesTableBuilder;