'use strict';
'use es6';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _immutable = require('immutable');

var _Distance = require('../../data/Distance');

var _Distance2 = _interopRequireDefault(_Distance);

var _DistanceUnit = require('../../data/DistanceUnit');

var _DistanceUnit2 = _interopRequireDefault(_DistanceUnit);

var _NearbyDriver = require('../../data/NearbyDriver');

var _NearbyDriver2 = _interopRequireDefault(_NearbyDriver);

var _DistanceCalculator = require('../calculators/DistanceCalculator');

var _DistanceCalculator2 = _interopRequireDefault(_DistanceCalculator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var NearbyDriversTranslator = function () {
  function NearbyDriversTranslator() {
    _classCallCheck(this, NearbyDriversTranslator);
  }

  _createClass(NearbyDriversTranslator, null, [{
    key: 'translate',
    value: function translate(response, location) {
      if (!('nearby_drivers' in response)) {
        throw new ReferenceError('expected nearby_drivers field');
      }

      var nearbyDrivers = response.nearby_drivers;

      if (!Array.isArray(nearbyDrivers)) {
        throw new TypeError('expected nearby_drivers to be an array');
      }

      return (0, _immutable.List)(nearbyDrivers.map(function (nearbyDriver) {
        return NearbyDriversTranslator.translateNearbyDriver(nearbyDriver, location.coordinate);
      }));
    }
  }, {
    key: 'translateNearbyDriver',
    value: function translateNearbyDriver(nearbyDriver, coordinate) {
      if (!('ride_type' in nearbyDriver)) {
        throw new ReferenceError('expected ride_type field');
      }

      if (!('drivers' in nearbyDriver)) {
        throw new ReferenceError('expected drivers field');
      }

      var rideType = nearbyDriver.ride_type;

      if (typeof rideType !== 'string') {
        throw new TypeError('expected ride_type to be a string');
      }

      var drivers = nearbyDriver.drivers;

      if (!Array.isArray(drivers)) {
        throw new TypeError('expected drivers to be an array');
      }

      var closestDistance = new _Distance2.default({
        value: Infinity,
        unit: _DistanceUnit2.default.MILE
      });

      drivers.forEach(function (driver) {
        if (!('locations' in driver)) {
          throw new ReferenceError('expected locations field');
        }

        var locations = driver.locations;

        if (!Array.isArray(locations)) {
          throw new TypeError('expected locations to be an array');
        }

        locations.forEach(function (location) {

          if (!('lat' in location)) {
            throw new ReferenceError('expected lat field');
          }

          if (!('lng' in location)) {
            throw new ReferenceError('expected lng field');
          }

          var distance = _DistanceCalculator2.default.calculateDistance(coordinate, {
            latitude: location.lat,
            longitude: location.lng
          });

          if (distance.value < closestDistance.value) {
            closestDistance = distance;
          }
        });
      });

      return new _NearbyDriver2.default({
        rideType: rideType,
        distance: closestDistance
      });
    }
  }]);

  return NearbyDriversTranslator;
}();

exports.default = NearbyDriversTranslator;