'use strict';
'use es6';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _immutable = require('immutable');

var _Distance = require('../../data/Distance');

var _Distance2 = _interopRequireDefault(_Distance);

var _DistanceUnit = require('../../data/DistanceUnit');

var _DistanceUnit2 = _interopRequireDefault(_DistanceUnit);

var _Duration = require('../../data/Duration');

var _Duration2 = _interopRequireDefault(_Duration);

var _TimeUnit = require('../../data/TimeUnit');

var _TimeUnit2 = _interopRequireDefault(_TimeUnit);

var _PriceRange = require('../../data/PriceRange');

var _PriceRange2 = _interopRequireDefault(_PriceRange);

var _RideEstimate = require('../../data/RideEstimate');

var _RideEstimate2 = _interopRequireDefault(_RideEstimate);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var RideEstimatesTranslator = function () {
  function RideEstimatesTranslator() {
    _classCallCheck(this, RideEstimatesTranslator);
  }

  _createClass(RideEstimatesTranslator, null, [{
    key: 'translate',
    value: function translate(response) {
      if (!('cost_estimates' in response)) {
        throw new ReferenceError('expected cost_estimates field');
      }

      var costEstimates = response.cost_estimates;

      if (!Array.isArray(costEstimates)) {
        throw new TypeError('expected cost_estimates to be an array');
      }

      return (0, _immutable.List)(costEstimates.map(function (costEstimate) {
        return RideEstimatesTranslator.translateCostEstimate(costEstimate);
      }));
    }
  }, {
    key: 'translateCostEstimate',
    value: function translateCostEstimate(costEstimate) {

      if (!('estimated_duration_seconds' in costEstimate)) {
        throw new ReferenceError('expected estimated_duration_seconds field');
      }

      if (!('estimated_distance_miles' in costEstimate)) {
        throw new ReferenceError('expected estimated_distance_miles field');
      }

      if (!('estimated_cost_cents_max' in costEstimate)) {
        throw new ReferenceError('expected estimated_cost_cents_max field');
      }

      if (!('primetime_percentage' in costEstimate)) {
        throw new ReferenceError('expected primetime_percentage field');
      }

      if (!('is_valid_estimate' in costEstimate)) {
        throw new ReferenceError('expected is_valid_estimate field');
      }

      if (!('currency' in costEstimate)) {
        throw new ReferenceError('expected currency field');
      }

      if (!('estimated_cost_cents_min' in costEstimate)) {
        throw new ReferenceError('expected estimated_cost_cents_min field');
      }

      if (!('display_name' in costEstimate)) {
        throw new ReferenceError('expected display_name field');
      }

      var estimatedDurationSeconds = costEstimate.estimated_duration_seconds;

      if (!Number.isInteger(estimatedDurationSeconds)) {
        throw new TypeError('expected estimated_duration_seconds to be an integer');
      }

      var estimatedDistanceMiles = costEstimate.estimated_distance_miles;

      if (typeof estimatedDistanceMiles !== 'number') {
        throw new TypeError('expected estimated_distance_miles to be a number');
      }

      var estimatedCostCentsMax = costEstimate.estimated_cost_cents_max;

      if (!Number.isInteger(estimatedCostCentsMax)) {
        throw new TypeError('expected estimated_cost_cents_max to be an integer');
      }

      var primetimePercentage = costEstimate.primetime_percentage;

      if (typeof primetimePercentage !== 'string') {
        throw new TypeError('expected primetime_percentage to be a string');
      }

      var isValidEstimate = costEstimate.is_valid_estimate;

      if (!(typeof isValidEstimate === 'undefined' ? 'undefined' : _typeof(isValidEstimate)) === 'boolean') {
        throw new TypeError('expected is_valid_estimate to be an boolean');
      }

      var currency = costEstimate.currency;

      if (typeof currency !== 'string') {
        throw new TypeError('expected currency to be a string');
      }

      var estimatedCostCentsMin = costEstimate.estimated_cost_cents_min;

      if (!Number.isInteger(estimatedCostCentsMin)) {
        throw new TypeError('expected estimated_cost_cents_min to be an integer');
      }

      var displayName = costEstimate.display_name;

      if (typeof displayName !== 'string') {
        throw new TypeError('expected display_name to be a string');
      }

      return new _RideEstimate2.default({
        displayName: displayName,
        estimatedDuration: new _Duration2.default({
          length: estimatedDurationSeconds,
          unit: _TimeUnit2.default.SECOND
        }),
        estimatedDistance: new _Distance2.default({
          value: estimatedDistanceMiles,
          unit: _DistanceUnit2.default.MILE
        }),
        isValidEstimate: isValidEstimate,
        primetimePercentage: parseInt(primetimePercentage),
        priceRange: new _PriceRange2.default({
          min: estimatedCostCentsMin,
          max: estimatedCostCentsMax,
          currencyCode: currency
        })
      });
    }
  }]);

  return RideEstimatesTranslator;
}();

exports.default = RideEstimatesTranslator;